#!/usr/bin/env ruby
# scrivwatch.rb by Brett Terpstra, 2011
# Watch a Scrivener project for changes and update a preview file for Marked
# Usage: scrivwatch.rb /path/to/document.scriv
# <http://markedapp.com>

trap("SIGINT") { exit }

if ARGV.length != 1 || ARGV[0] !~ /\.scriv\/?$/
  puts "Usage: scrivwatch.rb /path/to/document.scriv"
  exit
end

watch_folder = File.expand_path(ARGV[0].gsub(/\/$/,'')+"/Files/Docs/")
watch_types = ['rtf']
marked_note = File.expand_path("~/Marked Preview.md")

while true do # repeat infinitely
  files = []
  watch_types.each {|type|
    files += Dir.glob( File.join( watch_folder, "**", "*.#{type}" ) )
  } # collect a list of files of specified type
  new_hash = files.collect {|f| [ f, File.stat(f).mtime.to_i ] } # create a hash of timestamps
  hash ||= new_hash
  diff_hash = new_hash - hash # check for changes
  
  unless diff_hash.empty? # if changes were found in the timestamps
    hash = new_hash
    # Run the most recently-changed filename through textutil to turn rtf into txt
    note = %x{/usr/bin/textutil -convert txt -stdout "#{diff_hash[0][0]}"}
    # write the result to the preview file
    watch_note = File.new("#{marked_note}",'w') 
    watch_note.puts note
    watch_note.close
  end
  
  sleep 1
end